@@ -113,6 +113,15 @@ class Source(object):
     def __lt__(self, other):
         return self.name < other.name
 
+    def __le__(self, other):
+        return self.name <= other.name
+
+    def __gt__(self, other):
+        return self.name > other.name
+
+    def __ge__(self, other):
+        return self.name >= other.name
+
     def __repr__(self):
         return json.dumps(self.__json__(), indent=4)
 
